@@ -53,6 +53,7 @@ API_VERSION_REQUEST_HEADER = 'X-OpenStack-Manila-API-Version'
 EXPERIMENTAL_API_REQUEST_HEADER = 'X-OpenStack-Manila-API-Experimental'
 
 V1_SCRIPT_NAME = '/v1'
+V2_SCRIPT_NAME = '/v2'
 
 
 class Request(webob.Request):
@@ -218,10 +219,11 @@ class Request(webob.Request):
         Microversions starts with /v2, so if a client sends a /v1 URL, then
         ignore the headers and request 1.0 APIs.
         """
-
-        if not self.script_name:
+        if not self.script_name or not (V1_SCRIPT_NAME in self.script_name or
+                                        V2_SCRIPT_NAME in self.script_name):
+            # The request is on the base URL without a major version specified
             self.api_version_request = api_version.APIVersionRequest()
-        elif self.script_name == V1_SCRIPT_NAME:
+        elif V1_SCRIPT_NAME in self.script_name:
             self.api_version_request = api_version.APIVersionRequest('1.0')
         else:
             if API_VERSION_REQUEST_HEADER in self.headers:
@@ -863,7 +865,7 @@ class Resource(wsgi.Application):
             for hdr, val in response.headers.items():
                 val = utils.convert_str(val)
                 response.headers[hdr] = val
-
+            _set_request_id_header(request, response.headers)
             if not request.api_version_request.is_null():
                 response.headers[API_VERSION_REQUEST_HEADER] = (
                     request.api_version_request.get_string())
